@@ -16,12 +16,12 @@
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ##=============================================================================
 
-import _gecode
+import gecode._gecode as _gecode
 import re
 
 __all__ = ['space','intset']
 
-bindings_version = (0, 15)
+bindings_version = (0, 16)
 
 space = _gecode.space
 intset = _gecode.intset
